ATG Engine is an advanced Python module for developing text based games. It uses simple definitions and functions to reduce your code by nearly a half. You can install this package at PyPI. I wish you all a happy journey on making your text-based game.

PS : This game is in beta so if you want some more features or find some bugs please tell me.